@@ -5,25 +5,25 @@
 
 /* Package information */
 #define PACKAGE           "tasksh"
-#define VERSION           "1.0.0"
+#define VERSION           "1.1.0"
 #define PACKAGE_BUGREPORT "support@taskwarrior.org"
 #define PACKAGE_NAME      "tasksh"
 #define PACKAGE_TARNAME   "tasksh"
-#define PACKAGE_VERSION   "1.0.0"
-#define PACKAGE_STRING    "tasksh 1.0.0"
+#define PACKAGE_VERSION   "1.1.0"
+#define PACKAGE_STRING    "tasksh 1.1.0"
 
 #define CMAKE_BUILD_TYPE  ""
 
 /* Localization */
-#define PACKAGE_LANGUAGE 1
-#define LANGUAGE_ENG_USA 1
+#define PACKAGE_LANGUAGE 
+#define LANGUAGE_ENG_USA 
 
 /* git information */
 #define HAVE_COMMIT
 
 /* cmake information */
 #define HAVE_CMAKE
-#define CMAKE_VERSION "2.8.11.1"
+#define CMAKE_VERSION "3.6.1"
 
 /* Compiling platform */
 /* #undef LINUX */
@@ -42,8 +42,19 @@
 #define HAVE_READLINE
 
 /* Found the pthread library */
-#define HAVE_LIBPTHREAD
+/* #undef HAVE_LIBPTHREAD */
 
 /* Found wordexp.h */
 /* #undef HAVE_WORDEXP */
 
+/* Found tm.tm_gmtoff struct member */
+/* #undef HAVE_TM_GMTOFF */
+
+/* Found st.st_birthtime struct member */
+/* #undef HAVE_ST_BIRTHTIME */
+
+/* Functions */
+/* #undef HAVE_GET_CURRENT_DIR_NAME */
+/* #undef HAVE_TIMEGM */
+/* #undef HAVE_UUID_UNPARSE_LOWER */
+
